##  Access Your Workspace
The first user who registers for a workspace becomes the default administrator. Workspace administrators have extensive rights and can make significant changes to the workspace. We recommend assigning this role to enterprise architects or users with strong IT skills and expertise.
An onboarding manager from SAP LeanIX provisions a workspace according to your contract and sends an access link via email. Follow the link to set up your credentials for the workspace. Once you get access, you can invite other users to your workspace.
If you are not the primary workspace administrator, your administrator invites you to your organization’s workspace. Follow the link in the invitation email to set your credentials, then sign in to the workspace.
